"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _stringify = _interopRequireDefault(require("@babel/runtime-corejs2/core-js/json/stringify"));

var _extends2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/extends"));

var MiniCssExtractPlugin = require('mini-css-extract-plugin');

var UglifyJSPlugin = require('uglifyjs-webpack-plugin');

var findWorkspaceRoot = require('find-yarn-workspace-root'); // const hash = require('../utils/hash')


var path = require('path');

var rulesAssets = require('../utils/rules.assets');

var rulesJavascript = require('../utils/rules.javascript');

var rulesStyles = require('../utils/rules.styles');

var webpack = require('webpack');

module.exports = function provider(options) {
  options = (0, _extends2.default)({
    babel: require('babel-preset-frontful/browser'),
    cache: false,
    index: './src/browser/index.js',
    sourceMaps: true
  }, options);
  var cwd = process.cwd();
  var workspaceRoot = findWorkspaceRoot(cwd);
  var workspaceNodeModules = workspaceRoot ? "".concat(workspaceRoot, "/node_modules") : undefined;
  return {
    mode: 'production',
    cache: options.cache,
    context: cwd,
    devtool: options.sourceMaps && 'source-map',
    target: 'web',
    stats: {
      children: false
    },
    performance: {
      hints: false
    },
    entry: {
      main: [require.resolve('../../../utils/coldreload/browser.js'), options.index]
    },
    output: {
      path: path.resolve(cwd, './build/browser/assets/'),
      filename: "[contenthash].[name].js",
      publicPath: '/assets/'
    },
    optimization: {
      splitChunks: {
        cacheGroups: {
          vendor: {
            chunks: 'initial',
            name: 'vendor',
            enforce: true,
            test: function test(module) {
              return module.context && module.context.indexOf('node_modules') >= 0;
            }
          }
        }
      },
      minimizer: [new UglifyJSPlugin({
        uglifyOptions: {},
        sourceMap: options.sourceMaps
      })]
    },
    plugins: [new MiniCssExtractPlugin({
      filename: "[contenthash].[name].css"
    }), new webpack.optimize.OccurrenceOrderPlugin(), new webpack.DefinePlugin({
      'process.env': {
        NODE_ENV: (0, _stringify.default)(process.env.NODE_ENV),
        IS_BROWSER: (0, _stringify.default)(true)
      }
    }), new webpack.LoaderOptionsPlugin({
      options: {
        postcss: function postcss() {
          return [require('autoprefixer')({// browsers: 'last 4 version'
          })];
        }
      }
    })],
    module: {
      rules: [].concat(rulesJavascript({
        babel: options.babel,
        cache: options.cache
      }), rulesAssets(), rulesStyles({
        browser: true
      }))
    },
    resolve: {
      extensions: ['.js', '.ts', '.jsx', '.tsx'],
      mainFields: ['jsnext:main', 'browser', 'main'],
      symlinks: false,
      modules: [workspaceNodeModules || cwd + '/node_modules', 'node_modules']
    }
  };
};