"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _extends2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/extends"));

var commonConfig = require('frontful-common/config');

var findWorkspaceRoot = require('find-yarn-workspace-root');

var nodeExternals = require('webpack-node-externals');

var path = require('path');

var rulesAssets = require('../utils/rules.assets');

var rulesJavascript = require('../utils/rules.javascript');

var rulesStyles = require('../utils/rules.styles');

var webpack = require('webpack');

module.exports = function provider(options) {
  options = (0, _extends2.default)({
    babel: require('babel-preset-frontful/server'),
    cache: true,
    index: './src/server/index.js',
    sourceMaps: true
  }, options);
  var cwd = process.cwd();
  var workspaceRoot = findWorkspaceRoot(cwd);
  var workspaceNodeModules = workspaceRoot ? "".concat(workspaceRoot, "/node_modules") : 'node_modules';
  var nodeExternalsWhitelist = commonConfig.packages.concat(['core-js', 'corejs2']);
  return {
    mode: 'development',
    cache: options.cache,
    context: cwd,
    devtool: options.sourceMaps && 'source-map',
    externals: [nodeExternals({
      modulesDir: workspaceNodeModules,
      // includeAbsolutePaths: true,
      whitelist: function whitelist(module) {
        return nodeExternalsWhitelist.find(function (name) {
          return module.includes(name);
        });
      }
    })],
    target: 'node',
    stats: {
      children: false
    },
    performance: {
      hints: false
    },
    entry: {
      server: [options.index]
    },
    output: {
      path: path.resolve(cwd, './build/browser/assets/'),
      filename: "../../server/[name].js",
      publicPath: '/assets/',
      libraryTarget: 'commonjs-module',
      devtoolModuleFilenameTemplate: '[absolute-resource-path]' // devtoolModuleFilenameTemplate: (info) => {
      //   if (info.absoluteResourcePath.includes(cwd)) {
      //     return `${info.absoluteResourcePath}`
      //   }
      //   else {
      //     return `frontful:${info.absoluteResourcePath}`
      //   }
      // },

    },
    plugins: [new webpack.optimize.OccurrenceOrderPlugin(), new webpack.NoEmitOnErrorsPlugin(), new webpack.LoaderOptionsPlugin({
      options: {
        postcss: function postcss() {
          return [];
        }
      }
    })],
    module: {
      rules: [].concat(rulesJavascript({
        babel: options.babel,
        cache: options.cache
      }), rulesAssets(), rulesStyles({
        browser: false
      }))
    },
    resolve: {
      extensions: ['.js', '.ts', '.jsx', '.tsx'],
      mainFields: ['jsnext:main', 'browser', 'main'],
      symlinks: true,
      modules: [workspaceNodeModules // workspaceNodeModules || (cwd + '/node_modules'),
      // 'node_modules',
      ],
      alias: commonConfig.alias
    }
  };
};