"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _promise = _interopRequireDefault(require("@babel/runtime-corejs2/core-js/promise"));

var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/classCallCheck"));

var _createClass2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/createClass"));

var Bundle = require('./Bundle');

var MemoryFS = require('memory-fs');

var bundle = require('../../utils/bundle');

var chalk = require('chalk');

var commonConfig = require('frontful-common/config');

var config = require('../../config');

var deferred = require('../../utils/deferred');

var errorParser = require('../../utils/errorParser');

var fs = require('fs');

var path = require('path');

var printStats = require('../../utils/printStats');

var requireFile = require('../../utils/requireFile');

var server = require('../../utils/server');

var rimraf = require('rimraf');

process.env.PORT = process.env.PORT || config.server.port || 8080;
process.env.HOST = process.env.HOST || "http://localhost:".concat(process.env.PORT);
var ignored = new RegExp("(node_modules.*node_modules)|(node_modules(\\\\|\\/)(?!(".concat(commonConfig.packages.join('|'), ")(\\\\|\\/)))"));

module.exports =
/*#__PURE__*/
function () {
  function Development() {
    var _this = this;

    (0, _classCallCheck2.default)(this, Development);
    rimraf.sync(path.resolve(process.cwd(), 'build'));
    rimraf.sync(path.resolve(process.cwd(), 'stats'));
    this.fs = config.memory ? new MemoryFS() : null;

    var getServerFilename = function getServerFilename() {
      return _this.server && _this.server.filename;
    };

    var getFileSystem = function getFileSystem() {
      return _this.fs || fs;
    };

    require('source-map-support').install({
      handleUncaughtExceptions: false,
      hookRequire: true,
      environment: 'node',
      retrieveSourceMap: function retrieveSourceMap(source) {
        try {
          if (source === getServerFilename()) {
            return {
              url: source,
              map: getFileSystem().readFileSync(source.replace(/\.js$/i, '.js.map'), 'utf8')
            };
          }
        } catch (error) {}

        return null;
      }
    });

    this.options = {
      stats: {
        children: false,
        chunkModules: false,
        chunks: false,
        colors: true,
        hash: false,
        modules: false,
        timings: false,
        version: false
      }
    };
    this.server = {
      bundle: new Bundle({
        config: config.server.webpack,
        fs: this.fs
      }),
      filename: null,
      requestHandler: null,
      httpServer: null,
      compile: null,
      stats: null
    };
    this.browser = {
      bundle: new Bundle({
        config: config.browser.webpack,
        fs: this.fs
      }),
      compile: null,
      stats: null
    };
    this.compiled = false;
    this.compile = null;
  }

  (0, _createClass2.default)(Development, [{
    key: "startHandler",
    value: function startHandler(bundle) {
      var _this2 = this;

      if (this[bundle].compile) {
        this[bundle].compile.reject();
      }

      this[bundle].compile = deferred();

      if (this.server.compile && this.browser.compile) {
        if (this.compile) {
          this.compile.reject();
        }

        this.compile = deferred();
        this[bundle].compile.promise.then(this.compile.resolve).catch(function () {});

        _promise.default.all([this.server.compile.promise, this.browser.compile.promise, this.compile.promise]).then(function (stats) {
          var serverStats = stats[0],
              browserStats = stats[1];

          if (serverStats.hasErrors() && (!_this2.browser.stats || !_this2.browser.stats.hasErrors())) {
            printStats(false, serverStats);
          } else if (browserStats.hasErrors() && (!_this2.server.stats || !_this2.server.stats.hasErrors())) {
            printStats(false, browserStats);
          } else {
            if (_this2.compiled) {
              console.log(chalk.green("Application rebuilt"));

              for (var id in require.cache) {
                if (!ignored.test(id)) {
                  delete require.cache[id];
                }
              }

              require('frontful-config');

              _this2.server.requestHandler = requireFile(_this2.server.filename, {
                fs: _this2.fs
              });
              global.frontful.environment.coldreload.reload();
            }
          }

          _this2.server.stats = serverStats;
          _this2.browser.stats = browserStats;
        }).catch(function (e) {
          return e ? console.log(errorParser(e).colorful) : null;
        });
      }
    }
  }, {
    key: "endHandler",
    value: function endHandler(bundle, stats) {
      this[bundle].compile.resolve(stats);
    }
  }, {
    key: "start",
    value: function start() {
      var _this3 = this;

      _promise.default.all([this.server.bundle.watch(this.startHandler.bind(this, 'server'), this.endHandler.bind(this, 'server')), this.browser.bundle.watch(this.startHandler.bind(this, 'browser'), this.endHandler.bind(this, 'browser'))]).then(function (stats) {
        printStats(false, stats);
        console.log(chalk.green("Application built"));
        bundle(stats[1].toJson({
          children: false,
          chunkModules: false,
          chunks: false,
          assets: true,
          hash: false,
          modules: false,
          timings: false,
          version: false
        }).assetsByChunkName);

        require('frontful-config');

        require('../../utils/coldreload/server');

        _this3.server.filename = path.resolve(config.server.webpack.output.path, stats[0].compilation.entrypoints.get('server').chunks[0].files[0]);
        _this3.server.requestHandler = requireFile(_this3.server.filename, {
          fs: _this3.fs
        });
        var httpServer = server(function (req, res) {
          return _this3.server.requestHandler(req, res);
        }, {
          fs: _this3.fs,
          assets: config.server.assets
        });
        global.frontful.environment.coldreload.start(httpServer);
      }).then(function () {
        _this3.compiled = true;
      }).catch(function (e) {
        console.log(errorParser(e).colorful);
        process.exit(1);
      });
    }
  }]);
  return Development;
}();