"use strict";

var chalk = require('chalk');

var stripAnsi = require('strip-ansi');

module.exports = function errorParser(e) {
  var result = [],
      where,
      what,
      how;

  try {
    var stack = e.stack.replace(/^.*\n/i, '').replace(RegExp(process.cwd().replace(/\\/gi, '\\\\'), 'gi'), '.').replace(/\.[\\/]build[\\/]server[\\/]frontful:/gi, '').replace(/\(.+webpack:\//gi, '(./').replace(/.*__webpack_require__.*\n/ig, '').replace(/.*\(build\/.*\n/ig, '').match(/\(.*\)/gi).map(function (item) {
      return item.substr(1, item.length - 2).replace(/:(\d+:\d+)/gi, ' ($1)');
    });
    where = "ERROR in ".concat(stack.splice(0, 1));
    what = "".concat(e.name, ": ").concat(e.message);
    how = stack.map(function (item) {
      return " @ ".concat(item);
    }).join('\n');
    result.push('');
    result.push(chalk.red.bold(where));
    result.push(chalk.red.bold(what));
    result.push('');
    result.push(how);
    result.push('');
  } catch (_e) {
    result = [e.stack];
  }

  var joined = result.join('\n');
  return {
    colorful: joined,
    string: stripAnsi(joined),
    details: {
      where: where,
      what: what,
      how: how
    }
  };
};