"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _keys = _interopRequireDefault(require("@babel/runtime-corejs2/core-js/object/keys"));

var _extends2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/extends"));

var _isArray = _interopRequireDefault(require("@babel/runtime-corejs2/core-js/array/is-array"));

var chalk = require('chalk');

var pad = require('pad');

var path = require('path');

var statsOptions = {
  children: false,
  chunkModules: false,
  chunks: false,
  assets: true,
  colors: true,
  hash: false,
  modules: false,
  timings: false,
  version: false
};

module.exports = function printStats(printSize, items) {
  items = (0, _isArray.default)(items) ? items : [items];
  var stats = {
    time: null,
    folder: {}
  };
  var context = path.resolve(process.cwd(), 'build');
  var base = path.resolve(context, 'browser/assets');
  var maxSizeLength = 0;
  var error = false;
  items.forEach(function (item) {
    if (!error) {
      if (item.hasErrors()) {
        error = true;
        console.log(item.toString((0, _extends2.default)({}, statsOptions, {
          assets: false
        })));
      } else {
        var jsonStats = item.toJson(statsOptions);
        jsonStats.assets.forEach(function (asset) {
          var filePath = path.resolve(base, asset.name);
          var file = path.basename(filePath);
          var size = "".concat((asset.size / 1024.0).toFixed(2), " kB");
          maxSizeLength = Math.max(maxSizeLength, size.length);
          var folder = '.' + filePath.replace(process.cwd(), '').replace(file, '').replace(/[\\/]$/, '');
          stats.folder[folder] = stats.folder[folder] || [];
          stats.folder[folder].push({
            file: file,
            size: size
          });
        });
      }
    }
  });

  if (!error) {
    console.log();
    (0, _keys.default)(stats.folder).forEach(function (folder) {
      console.log("".concat(chalk.bold.white(folder)));
      var files = [];
      stats.folder[folder].forEach(function (item) {
        if (files.indexOf(item.file) === -1) {
          console.log(" ".concat(printSize ? chalk.gray(pad(maxSizeLength, item.size) + ' ') : '').concat(chalk.green(item.file)));
          files.push(item.file);
        }
      });
    });
  }

  console.log();
};