"use strict";

var chalk = require('chalk');

var getAssetHandler = require('./getAssetHandler');

var http = require('http');

var errorParser = require('./errorParser');

var getErrorHandler = require('./getErrorHandler');

global.frontful = global.frontful || {};
global.frontful.environment = global.frontful.environment || {};
global.frontful.environment.error = global.frontful.environment.error || {};
global.frontful.environment.error.parser = errorParser;
global.frontful.environment.error.getHandler = getErrorHandler;

module.exports = function (handler, options) {
  options = options || {};
  var cumulativeHandler;

  if (options.assets) {
    var assetHandler = getAssetHandler({
      fs: options.fs
    });

    cumulativeHandler = function cumulativeHandler(req, res) {
      assetHandler(req, res, function () {
        handler(req, res);
      });
    };
  } else {
    cumulativeHandler = handler;
  }

  var server = http.createServer(cumulativeHandler);
  var listener = server.listen(process.env.PORT, function (error) {
    console[error ? 'error' : 'log'](error || chalk.green("Server started on port ".concat(process.env.PORT)));
  });
  global.frontful.environment.server = server;
  global.frontful.environment.listener = listener;
  return server;
};